package Mojolicious::Plugin::Fondation::Controller::Base;
$Mojolicious::Plugin::Fondation::Controller::Base::VERSION = '0.04';
# ABSTRACT: Base controller class for Fondation controllers

use Mojo::Base 'Mojolicious::Controller', -signatures;


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Mojolicious::Plugin::Fondation::Controller::Base - Base controller class for Fondation controllers

=head1 VERSION

version 0.04

=head1 AUTHOR

Daniel Brosseau <dab@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2026 by Daniel Brosseau.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
